@@ -1,6 +1,6 @@
 # ABSTRACT: ArangoDB Collection object
 package Arango::Tango::Collection;
-$Arango::Tango::Collection::VERSION = '0.008';
+$Arango::Tango::Collection::VERSION = '0.009';
 use warnings;
 use strict;
 
@@ -20,6 +20,22 @@ sub document_paths {
     return $self->{arango}->_api('all_keys', { database => $self->{database}, collection => $self->{name}, type => "path"})->{result}
 }
 
+sub get_access_level {
+    my ($self, $username) = @_;
+    return $self->{arango}->get_access_level($self->{database}, $self->{name}, $username );
+}
+
+sub clear_access_level {
+    my ($self, $username) = @_;
+    return $self->{arango}->clear_access_level($self->{database}, $self->{name}, $username );
+}
+
+sub set_access_level {
+    my ($self, $username, $grant) = @_;
+    return $self->{arango}->set_access_level($self->{database}, $self->{name}, $username, $grant);
+}
+
+
 1;
 
 __END__
@@ -34,7 +50,7 @@ Arango::Tango::Collection - ArangoDB Collection object
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 USAGE
 
@@ -56,6 +72,24 @@ Stores a document in specified collection
 
 Lists all collection document as their paths in the database. Returns a hash reference.
 
+=head2 C<get_access_level>
+
+    my $perms = $db->get_access_level($user)
+
+Fetch the collection access level for a specific user.
+
+=head2 C<set_access_level>
+
+    $db->set_access_level($user, 'none')
+
+Sets the collection access level for a specific user.
+
+=head2 C<clear_access_level>
+
+    $db->clear_access_level($user, 'none')
+
+Clears the collection access level for a specific user.
+
 =head1 AUTHOR
 
 Alberto Simões <ambs@cpan.org>
